==> m4e_sdk-0.0.3-dev.6.tar.gz: lib/src/m4e_forms/user/m4e_user_form.dart <==
import 'package:equatable/equatable.dart';
import 'package:flutter/cupertino.dart';

import '../../core/core.dart';
import '../../models/models.dart';

class M4eUserForm extends Equatable {
  final String shortName;
  final String firstName;
  final String lastName;
  final M4ePhoneNumber phoneNumber;
  final int joined;
  final String publicKey;

  const M4eUserForm._(
    this.shortName,
    this.firstName,
    this.lastName,
    this.phoneNumber,
    this.joined,
    this.publicKey,
  );

  factory M4eUserForm({
    @required String firstName,
    @required String lastName,
    @required M4ePhoneNumber phoneNumber,
  }) {
    assert(firstName != null, 'M4eUserForm [firstName] should not be null');
    assert(lastName != null, 'M4eUserForm [lastName] should not be null');
    assert(phoneNumber != null, 'M4eUserForm [phoneNumber] should not be null');

    final _joined = DateTime.now().toTimestampSinceEpoch();
    final _shortName = "$firstName'_$lastName-${M4eUniqueId()}";

    // TODO: generate assymetric key-pair in sdk and cache and possibly export to hidden file system
    final _publicKey = 'demo-public-key';

    return M4eUserForm._(
        _shortName, firstName, lastName, phoneNumber, _joined, _publicKey);
  }

  Map<String, dynamic> toJson() {
    return {
      'user': {
        'shortName': this.shortName,
        'firstName': this.firstName,
        'lastName': this.lastName,
        'phone': this.phoneNumber.toJson(),
        'joined': this.joined,
      },
      'pubKey': this.publicKey
    };
  }

  @override
  List<Object> get props =>
      [shortName, firstName, lastName, phoneNumber, joined, publicKey];

  @override
  String toString() {
    return 'M4eUserForm(shortName: $shortName, firstName: $firstName, lastName: $lastName, phoneNumber: $phoneNumber, joined: $joined, publicKey: $publicKey, publicKey]: $publicKey])';
  }
}

==> m4e_sdk-0.0.4-dev.7.tar.gz: lib/src/m4e_forms/user/m4e_user_form.dart <==
import 'package:equatable/equatable.dart';
import 'package:flutter/cupertino.dart';

import '../../core/core.dart';
import '../../models/models.dart';

class M4eUserForm extends Equatable {
  final String shortName;
  final String firstName;
  final String lastName;
  final M4ePhoneNumber phoneNumber;
  final int joined;
  final String publicKey;

  const M4eUserForm._(
    this.shortName,
    this.firstName,
    this.lastName,
    this.phoneNumber,
    this.joined,
    this.publicKey,
  );

  factory M4eUserForm({
    @required String firstName,
    @required String lastName,
    @required M4ePhoneNumber phoneNumber,
  }) {
    assert(firstName != null, 'M4eUserForm [firstName] should not be null');
    assert(lastName != null, 'M4eUserForm [lastName] should not be null');
    assert(phoneNumber != null, 'M4eUserForm [phoneNumber] should not be null');

    final _joined = DateTime.now().toTimestampSinceEpoch();
    final _shortName = '${firstName}_$lastName-${M4eUniqueId()}';

    // TODO: generate assymetric key-pair in sdk and cache and possibly export to hidden file system
    final _publicKey = 'demo-public-key';

    return M4eUserForm._(
        _shortName, firstName, lastName, phoneNumber, _joined, _publicKey);
  }

  Map<String, dynamic> toJson() {
    return {
      'user': {
        'shortName': this.shortName,
        'firstName': this.firstName,
        'lastName': this.lastName,
        'phone': this.phoneNumber.toJson(),
        'joined': this.joined,
      },
      'pubKey': this.publicKey
    };
  }

  @override
  List<Object> get props =>
      [shortName, firstName, lastName, phoneNumber, joined, publicKey];

  @override
  String toString() {
    return 'M4eUserForm(shortName: $shortName, firstName: $firstName, lastName: $lastName, phoneNumber: $phoneNumber, joined: $joined, publicKey: $publicKey, publicKey]: $publicKey])';
  }
}
